Learn R Programming

ergm (version 4.2.3)

BDStratTNT-ergmProposal: TNT proposal with degree bounds

Description

Implements a TNT proposal with any subset of the following features:

  1. upper on degree, specified via the bd constraint's maxout, maxin, and attribs arguments

  2. stratification of proposals according to mixing type on a vertex attribute, specified via the strat hint;

  3. fixation of specified mixing types on a(nother) vertex attribute, specified via the blocks constraint.

Arguments

Details

ergm:::.formatProposalsHtml(ergm:::.buildProposalsList(proposal="BDStratTNT"))