CondDegreeMix-ergmProposal: MHp for degree mix constraints
Description
MHp for \(constraints= ~degreesmix\). Similar to InitErgmProposal.CondDegree, except that
the toggle is proposed only if the mixing matrix of degrees is preserved before and after the toggle.