CondInDegree-ergmProposal: MHp for idegree constraints
Description
MHp for \(constraints= ~idegrees\). For directed networks, randomly select two dyads with a
common head node, one having an edge one not, and propose to swap the tie from one tail to the other.