CondOutDegree-ergmProposal: MHp for odegree constraints
Description
MHp for \(constraints= ~odegrees\). For directed networks, randomly select two dyads with a
common tail node, one having an edge and one not, and propose to swap the tie from one head to the other.