Learn R Programming

ergm (version 4.12.0)

I-ergmConstraint: Substitute a formula into the constraints formula

Description

This is a convenience operator that can be used to paste terms constructed elsewhere into a formula.

Usage

# I(formula)

Arguments

formula

a constraints formula

See Also

base::I() (a.k.a. AsIs)

ergmConstraint for index of constraints and hints currently visible to the package.

ergm:::.formatTermKeywords("ergmConstraint", "I", "subsection")