Learn R Programming

ergm (version 4.2.3)

StdNormal-ergmReference: Standard Normal reference

Description

Specifies each dyad's baseline distribution to be the normal distribution with mean 0 and variance 1.

Usage

# StdNormal

Arguments

See Also

ergmReference for index of reference distributions currently visible to the package.