powered by
Specifies each dyad's baseline distribution to be continuous uniform between a and b: \(h(y)=1\) , with the support being [a, b].
a
b
[a, b]
# Unif(a,b)
minimum and maximum to the baseline discrete uniform distribution, both inclusive. Both values must be finite.
ergmReference for index of reference distributions currently visible to the package.
ergmReference