| asymmetric-ergmTerm | R Documentation |
This term adds one network statistic to the model equal to the
number of pairs of actors for which exactly one of
(i{\rightarrow}j) or (j{\rightarrow}i) exists.
# binary: asymmetric(attr=NULL, diff=FALSE, keep=NULL, levels=NULL)
attr |
quantitative attribute (see Specifying Vertex attributes and Levels ( |
diff |
Used in the same way as for the |
keep |
deprecated |
level |
Used in the same way as for the |
This term can only be used with directed networks.
The argument keep is retained for backwards compatibility and may be
removed in a future version. When both keep and levels are passed,
levels overrides keep. See nodal_attributes.
ergmTerm for index of model terms currently visible to the package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.