atleast-ergmTerm: Number of dyads with values greater than or equal to a threshold
Description
Adds the number of
statistics equal to the length of threshold
equaling to the number of dyads whose values equal or exceed the
corresponding element of threshold .
Usage
# valued: atleast(threshold=0)
Arguments
threshold
vector of numerical values
See Also
ergmTerm for index of model terms currently visible to the package.