| b1twostar-ergmTerm | R Documentation |
This term takes two nodal attributes. Assuming that there are
n_1 values of b1attr among the b1 nodes and n_2
values of b2attr among the b2 nodes, then the total number of
distinct categories of two stars according to these two attributes is
n_1(n_2)(n_2+1)/2. By default, this model term creates a distinct statistic
counting each of these categories.
# binary: b1twostar(b1attr, b2attr, base=NULL, b1levels=NULL, b2levels=NULL, levels2=NULL)
b1attr |
b1 nodes (actors in some contexts) (see Specifying Vertex attributes and Levels ( |
b2attr |
b2 nodes (events in some contexts). If |
b1levels, b2levels, base, levels2 |
used to leave some of the categories out (see Specifying Vertex attributes and Levels ( |
The argument base is retained for backwards compatibility and may be
removed in a future version. When both base and levels are passed,
levels overrides base. See nodal_attributes.
The argument base is retained for backwards compatibility and may be
removed in a future version. When both base and levels2 are passed,
levels2 overrides base. See nodal_attributes.
ergmTerm for index of model terms currently visible to the package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.