| b2twostar-ergmTerm | R Documentation |
This term is exactly the same as b1twostar except that the
roles of b1 and b2 are reversed.
# binary: b2twostar(b1attr, b2attr, base=NULL, b1levels=NULL, b2levels=NULL, levels2=NULL)
b1attr |
b1 nodes (actors in some contexts) (see Specifying Vertex attributes and Levels ( |
b2attr |
b2 nodes (events in some contexts). If |
b1levels, b2levels, base, levels2 |
used to leave some of the categories out (see Specifying Vertex attributes and Levels ( |
The argument base is retained for backwards compatibility and may be
removed in a future version. When both base and levels are passed,
levels overrides base. See nodal_attributes.
The argument base is retained for backwards compatibility and may be
removed in a future version. When both base and levels2 are passed,
levels2 overrides base. See nodal_attributes.
ergmTerm for index of model terms currently visible to the package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.