blockdiag-ergmConstraint-140bec05: Block-diagonal structure constraint

blockdiag-ergmConstraintR Documentation

Block-diagonal structure constraint

Description

Force a block-diagonal structure (and its bipartite analogue) on the network. Only dyads (i,j) for which attr(i)==attr(j) can have edges.

Usage

# blockdiag(attr, noncontig = "merge")

Arguments

attr

a vertex attribute specification (see Specifying Vertex attributes and Levels (?nodal_attributes) for details.)

noncontig

character: what to do if the blocks are not contiguous?

"merge"

A placeholder option, to treat them as the same block. It may be implemented in the future, and an explicit "stop" option added later.

"split"

Treat them as separate blocks.

Details

For bipartite graphs, blocks must be have the same ordering in both partitions. (They do not, however, require that all blocks be represented in both partitions, but those that overlap must have the same order.)

If multiple block-diagonal constraints are given, or if attr is a vector with multiple attribute names, blocks will be constructed on all attributes matching.

See Also

ergmConstraint for index of constraints and hints currently visible to the package.

\Sexpr[results=rd,stage=render]{ergm:::.formatTermKeywords("ergmConstraint", "blockdiag", "subsection")}

ergm documentation built on Feb. 18, 2026, 1:06 a.m.