For every value \(x\) in seq(min, max, by),
compute the number of dyads whose value is less than or equal
than \(x\). If not given, the range is autodetected based on
the values in the LHS network, subject to adjustment via margin
and nmax.
# valued: cdf(min = NULL, max = NULL, by = NULL, margin = 0.1, nmax = 100)range and step size for values at which to compute the CDF
autodetection of the range and step size; see Details.
If min, max, and/or by is missing, it is
automatically computed based on the LHS network's nonzero edge
values, specifically their range and resolution (smallest
observed difference between distinct values). Minimum and maximum
are taken from the minimal and the maximal edge values, and then
expanded by margin multiplied by their range, and rounded up to
the nearest multiple of the resolution. The step is set to the
smallest multiple of the resolution such that the total number of
statistics is no more than nmax.
atmost()
ergmTerm for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "cdf", "subsection")