This term adds one network statistic to the model for each element in d where the \(i\) th such statistic equals the number of dyads in the network with exactly d[i] shared partners.
Usage
# binary: ddsp(d, type="OTP")
Arguments
d
a vector of distinct integers
type
one of c("OTP", "ITP", "RTP", "OSP", "ISP")
See Also
ergmTerm for index of model terms currently visible to the package.