Learn R Programming

ergm (version 4.12.0)

degree1.5-ergmTerm: Degree to the 3/2 power

Description

This term adds one network statistic to the model equaling the sum over the actors of each actor's degree taken to the 3/2 power (or, equivalently, multiplied by its square root). This term is an undirected analog to the terms of SnVa10i;textualergm, equations (11) and (12). This term can only be used with undirected networks.

Usage

# binary: degree1.5

Arguments

See Also

ergmTerm for index of model terms currently visible to the package.

ergm:::.formatTermKeywords("ergmTerm", "degree1.5", "subsection")