degrees-ergmConstraint: Preserve the degree of each vertex of the given network
Description
Only networks
whose vertex degrees are the same as those in the network passed
in the model formula have non-zero probability. If the network is
directed, both indegree and outdegree are preserved.
Usage
# degrees
# nodedegrees
Arguments
See Also
ergmConstraint for index of constraints and hints currently visible to the package.