This term adds a statistic equal to the geometrically weighted edgewise (not dyadwise) shared partner distribution with decay parameter decay parameter.
# binary: dgwesp(decay, fixed=FALSE, cutoff=30, type="OTP")nonnegative decay parameter for the shared partner or selected directed analogue count; required if fixed=TRUE and ignored with a warning otherwise.
optional argument indicating
whether the decay parameter is fixed at the given value, or is to be fit as a curved
exponential-family model (see Hunter and Handcock, 2006). The
default is FALSE , which means the scale parameter is not
fixed and thus the model is a curved exponential family.
This optional argument sets the number of underlying ESP terms
to use in computing the statistics when fixed=FALSE, in order to reduce
the computational burden. Its default value can also be controlled by the
gw.cutoff term option control parameter. (See ?control.ergm.)
one of c("OTP", "ITP", "RTP", "OSP", "ISP").
ergmTerm for index of model terms currently visible to the package.