This term adds one
network statistic to the model for each element in d ; the \(i\) th
such statistic equals the number of dyads in the network with exactly
d[i] shared partners. This term can be used with directed and
undirected networks.
Usage
# binary: dsp(d)
Arguments
d
a vector of distinct integers
See Also
ergmTerm for index of model terms currently visible to the package.