This term adds one network statistic equal to the number of
edges (i.e. nonzero values) in the network. For undirected networks, edges
is equal to kstar(1); for directed networks, edges is equal to both
ostar(1) and istar(1).
Usage
# binary: edges
# valued: nonzero
# valued: edges
Arguments
See Also
ergmTerm for index of model terms currently visible to the package.