equalto-ergmTerm: Number of dyads with values equal to a specific value (within tolerance)
Description
Adds one statistic equal to the number of dyads whose values
are within tolerance of value , i.e., between
value-tolerance and value+tolerance , inclusive.
Usage
# valued: equalto(value=0, tolerance=0)
Arguments
value
numerical threshold
tolerance
numerical threshold
See Also
ergmTerm for index of model terms currently visible to the package.