Functions that have been superceed, were never documented, or will be removed from the package for other reasons
# S3 method for ergm
coef(object, ...)# S3 method for ergm
$(x, name)
convert_ergmlhs(lhs)
Arguments to deprecated functions.
See Extract.
coef(ergm): extracts the ergm parameters; may be
removed in favour of the default method once the number of ergm
objects with $coef elements in the wild is sufficiently low.
$: accesses elements of ergm objects;
needed for backwards compatibility when components get renamed.
convert_ergmlhs(): convert_ergmlhs converts old-style settings to new-style settings.