get.free.dyads will create a network object with only edges that are not targeted by ergm-constraints. get.miss.dyads creates a network object with only edges that are missing/not present (not missing in the NA sense) in a network subject to constraints
get.free.dyads(constraints)
get.miss.dyads(constraints, constraints.obs)InitConstraint.* functions for the model of interest and the
same list with +observed constraint appended if missing dyads
are present.