greaterthan-ergmTerm: Number of dyads with values strictly greater than a threshold
Description
Adds the number of statistics equal to the length of threshold
equaling to the number of dyads whose values exceed the
corresponding element of threshold .
Usage
# valued: greaterthan(threshold=0)
Arguments
threshold
a vector of numerical values
See Also
ergmTerm for index of model terms currently visible to the package.