Learn R Programming

ergm (version 4.12.0)

idegree1.5-ergmTerm: In-degree to the 3/2 power

Description

This term adds one network statistic to the model equaling the sum over the actors of each actor's indegree taken to the 3/2 power (or, equivalently, multiplied by its square root). This term is analogous to the term of SnVa10i;textualergm, equation (12). This term can only be used with directed networks.

Usage

# binary: idegree1.5

Arguments

See Also

ergmTerm for index of model terms currently visible to the package.

ergm:::.formatTermKeywords("ergmTerm", "idegree1.5", "subsection")