Learn R Programming

ergm (version 4.2.3)

idegrees-ergmConstraint: Preserve indegree for directed networks

Description

For directed networks, preserve the indegree of each vertex of the given network, while allowing outdegree to vary

Usage

# idegrees

Arguments

See Also

ergmConstraint for index of constraints and hints currently visible to the package.