Learn R Programming

ergm (version 3.8.0)

is.dyad.independent: Testing for dyad-independence

Description

These functions test whether an ERGM fit or formula is dyad-independent.

Usage

# S3 method for ergm
is.dyad.independent(object, ...)
# S3 method for formula
is.dyad.independent(object, 
                    response=NULL,
                    basis=NULL,
                    …)
# S3 method for conlist
is.dyad.independent(object, 
                    object.obs = NULL, 
                    ...)
# S3 method for ergm.model
is.dyad.independent(object, ...)
# S3 method for NULL
is.dyad.independent(object, ...)

Arguments

object

An ergm object or an ERGM formula.

response, basis

Name of the edge attribute whose value is to be modeled. See ergm.

object.obs

…

Unused at this time.

Value

TRUE if the model fit or one implied by the formula is dyad-independent; FALSE otherwise.

Details

Dyad independence is determined by checking if all of the constituent parts of the object (formula, ergm terms, etc) are flagged as dyad-independent.