This term adds one statistic to the
model equal to the number of isolates in the network. For an undirected
network, an isolate is defined to be any node with degree zero. For a
directed network, an isolate is any node with both in-degree and out-degree
equal to zero.
Usage
# binary: isolates
Arguments
See Also
ergmTerm for index of model terms currently visible to the package.