| mutual-ergmTerm | R Documentation |
In binary ERGMs, equal to the number of
pairs of actors i and j for which (i{\rightarrow}j)
and (j{\rightarrow}i) both exist.
For valued ERGMs, equal to \sum_{i<j} m(y_{i,j},y_{j,i}) ,
where m is determined by form argument: "min"
for \min(y_{i,j},y_{j,i}), "nabsdiff" for
-|y_{i,j},y_{j,i}|, "product" for
y_{i,j}y_{j,i}, and "geometric" for
\sqrt{y_{i,j}}\sqrt{y_{j,i}}. See \insertCiteKr12e;textualergm for a
discussion of these statistics. form="threshold" simply
computes the binary mutuality after
thresholding at threshold.
This term can only be used with directed networks.
# binary: mutual(same=NULL, by=NULL, diff=FALSE, keep=NULL, levels=NULL)
# valued: mutual(form="min",threshold=0)
same |
if the optional argument is passed
(see Specifying Vertex attributes and Levels ( |
by |
if the optional argument is passed (see Specifying Vertex attributes and Levels ( |
keep |
deprecated |
levels |
which statistics should be kept whenever the |
form, threshold |
variant to be used in the valued case. |
The argument keep is retained for backwards compatibility and may be
removed in a future version. When both keep and levels are passed,
levels overrides keep. See nodal_attributes.
ergmTerm for index of model terms currently visible to the package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.