| nodematch-ergmTerm | R Documentation |
When diff=FALSE , this term adds one network statistic
to the model, which counts the number of edges (i,j) for which
attr(i)==attr(j) . This is also called “uniform homophily”, because each group is assumed to have the same propensity for within-group ties. When multiple attribute names are given, the
statistic counts only ties for which all of the attributes
match. When diff=TRUE , p network statistics are added
to the model, where p is the number of unique values of the
attr attribute. The k th such statistic counts the
number of edges (i,j) for which attr(i) == attr(j) == value(k) , where value(k) is the k th
smallest unique value of the attr attribute. This is also called “differential homophily”, because each group is allowed to have a unique propensity for within-group ties. Note that a statistical test of uniform vs. differential homophily should be conducted using the ANOVA function.
By default, matches on all levels k are
counted. This works for both
diff=TRUE and diff=FALSE .
# binary: nodematch(attr, diff=FALSE, keep=NULL, levels=NULL)
# valued: nodematch(attr, diff=FALSE, keep=NULL, levels=NULL, form="sum")
# valued: match(attr, diff=FALSE, keep=NULL, levels=NULL, form="sum")
attr |
a vertex attribute specification (see Specifying Vertex attributes and Levels ( |
diff |
specify if the term has uniform or differential homophily |
keep |
deprecated |
levels |
this optional argument controls which levels of the attribute should be included and which should be excluded. (See Specifying Vertex
attributes and Levels ( |
form |
how to aggregate tie values in a valued ERGM: |
The argument keep is retained for backwards compatibility and may be
removed in a future version. When both keep and levels are passed,
levels overrides keep. See nodal_attributes.
ergmTerm for index of model terms currently visible to the package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.