This term adds one network statistic to the model equaling the sum over the actors of each actor's outdegree taken to the 3/2 power (or, equivalently, multiplied by its square root). This term is analogous to the term of SnVa10i;textualergm, equation (12). This term can only be used with directed networks.
# binary: odegree1.5ergmTerm for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "odegree1.5", "subsection")