Learn R Programming

ergm (version 4.2.3)

search.ergmProposals: Search the ERGM Proposals

Description

Searches through the ergm.proposals help page and prints out a list of proposals appropriate for the specified network's structural constraints, optionally restricting by additional keywords and search term matches.

Usage

search.ergmProposals(search, name, reference, constraints, packages)

Value

prints out the name and short description of matching terms, and invisibly returns them as a list. If name is specified, prints out the full definition for the named term.

Arguments

search

optional character search term to search for in the text of the term descriptions. Only matching terms will be returned. Matching is case insensitive.

name

optional character name of a specific proposal to return

reference

optional character to limit proposals to only those with a matching reference

constraints

optional character vector to limit proposals to only those with matching hard or soft constraints

packages

optional character vector indicating the subset of packages in which to search

Details

Uses grep internally to match the search terms against the proposal description, so search is currently matched as a single phrase. Keyword tags will only return a match if all of the specified tags are included in the proposal

See Also

See also ergm.proposals for the complete documentation

Examples

Run this code
# \donttest{
# find all of the proposals that mention triangles
search.ergmProposals('MH algorithm')

# print out the content for a specific proposals
search.ergmProposals(name='randomtoggle')

# find all proposals with required or optional constraints
search.ergmProposals(constraints='.dyads')

# find all proposals with references
search.ergmProposals(reference='Bernoulli')

# request proposals that mention triangle in the ergm package
search.ergmProposals('MH algorithm', packages='ergm')
# }

Run the code above in your browser using DataLab