Learn R Programming

ergm (version 4.2.3)

search.ergmReferences: Search the ERGM References

Description

Searches through the ergm.references help page and prints out a list of terms appropriate for the specified network's structural constraints, optionally restricting by additional keywords and search term matches.

Usage

search.ergmReferences(search, keywords, name, packages)

Value

prints out the name and short description of matching terms, and invisibly returns them as a list. If name is specified, prints out the full definition for the named term.

Arguments

search

optional character search term to search for in the text of the term descriptions. Only matching terms will be returned. Matching is case insensitive.

keywords

optional character vector of keyword tags to use to restrict the results (i.e. 'curved', 'triad-related')

name

optional character name of a specific term to return

packages

optional character vector indicating the subset of packages in which to search

Author

skyebend@uw.edu

Details

Uses grep internally to match the search terms against the term description, so search is currently matched as a single phrase. Keyword tags will only return a match if all of the specified tags are included in the term.

See Also

See also ergm.references for the complete documentation

Examples

Run this code
# \donttest{
# find all of the references that mention dyad
search.ergmReferences('dyad')

# search on multiple keywords
search.ergmReferences(keywords=c('binary','discrete'))

# print out the content for a specific reference
search.ergmReferences(name='Bernoulli')

# request the bipartite keyword in the ergm package
search.ergmReferences(keywords='binary', packages='ergm')
# }

Run the code above in your browser using DataLab