Learn R Programming

ergm (version 4.2.3)

simmelian-ergmTerm: Simmelian triads

Description

This term adds one statistic to the model equal to the number of Simmelian triads, as defined by Krackhardt and Handcock (2007). This is a complete sub-graph of size three.

Usage

# binary: simmelian

Arguments

See Also

ergmTerm for index of model terms currently visible to the package.