smallerthan-ergmTerm: Number of dyads with values strictly smaller than a threshold
Description
Adds the number of statistics equal to the length of threshold
equaling to the number of dyads whose values are exceeded by the
corresponding element of threshold .
Usage
# valued: smallerthan(threshold=0)
Arguments
threshold
vector of numerical values
See Also
ergmTerm for index of model terms currently visible to the package.