stergm is used for finding Separable Temporal ERGMs'
(STERGMs) Conditional MLE (CMLE) (Krivitsky and Handcock, 2010) and
Equilibrium Generalized Method of Moments Estimator (EGMME) (Krivitsky, 2009).stergm (nw,
formation,
dissolution,
estimate,
times=NULL,
offset.coef.form=NULL,
offset.coef.diss=NULL,
targets=NULL,
target.stats=NULL,
eval.loglik=FALSE,
control=control.stergm(),
verbose=FALSE,
...)network object (for EGMME); or
networkDynamic object, a
network.listergm-style formulas for the formation and
dissolution models, respectively.c(0,1) if nw is a
networkDynaergm-style formula specifying statistics whose
moments are used for the EGMME. Unused for CMLE and CMPLE.targets statistics that
EGMME will try to match.
Defaults to the
statistics of nw. Unused for CMLE and CMPLE.ergm for details.control.stergm.stergm returns an object of class stergm that is a list
consisting of the following elements:mcmc object containing target
statistics sampled at the estimate.ergm objects from fitting formation and dissolution,
respectively. For EGMME, stripped down ergm-like lists.print.stergm for details on how
an stergm object is printed. Note that the
method summary.stergm returns a summary of the
relevant parts of the stergm object in concise summary
format.ergm and ergm-terms for details. At
this time, only linear ERGM terms are allowed. Krivitsky PN, Handcock MS (2010). A Separable Model for Dynamic
Networks.
ergm-terms