This term adds one statistic to the model, equal to the number of triads in
the network that are transitive. The transitive triads are those of type
120D , 030T , 120U , or 300 in the categorization
of DaLe72s;textualergm. For details on the 16 possible triad types,
see ?triad.classify in the sna package.
Note the distinction from the ttriple term. This term can only be
used with directed networks.
# binary: transitiveergmTerm for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "transitive", "subsection")