Learn R Programming

ergm (version 4.12.0)

transitiveweights-ergmTerm: Transitive weights

Description

This statistic implements the transitive weights statistic defined by Kr12e;textualergm, Equation 13. For each of these options, the first (and the default) is more stable but also more conservative, while the second is more sensitive but more likely to induce a multimodal distribution of networks.

Usage

# valued: transitiveweights(twopath="min", combine="max", affect="min")

Arguments

twopath

the minimum of the constituent dyads ( "min" ) or their geometric mean ( "geomean" )

combine

the maximum of the 2-path strengths ( "max" ) or their sum ( "sum" )

affect

the minimum of the focus dyad and the combined strength of the two paths ( "min" ) or their geometric mean ( "geomean" )

See Also

ergmTerm for index of model terms currently visible to the package.

ergm:::.formatTermKeywords("ergmTerm", "transitiveweights", "subsection")