Implements a TNT proposal with any subset of the following features:
upper on degree, specified via the bd constraint's maxout, maxin, and attribs arguments
stratification of proposals according to mixing type on a vertex attribute, specified via the strat hint;
fixation of specified mixing types on a(nother) vertex attribute, specified via the blocks constraint.
ergm:::.formatProposalsHtml(ergm:::.buildProposalsList(proposal="BDStratTNT"))