powered by
This is a convenience operator that can be used to paste terms constructed elsewhere into a formula.
# I(formula)
a constraints formula
base::I() (a.k.a. AsIs)
base::I()
AsIs
ergmConstraint for index of constraints and hints currently visible to the package.
ergmConstraint
ergm:::.formatTermKeywords("ergmConstraint", "I", "subsection")