powered by
This is a convenience operator that can be used to paste terms constructed elsewhere into a formula.
# binary: I(formula)# valued: I(formula)
# valued: I(formula)
a one-sided ergm()-style formula with the terms to be evaluated
ergm()
base::I() (a.k.a. AsIs)
base::I()
AsIs
ergmTerm for index of model terms currently visible to the package.
ergmTerm
ergm:::.formatTermKeywords("ergmTerm", "I", "subsection")
data(florentine) (terms <- paste0("degree(", 0:5, ")")) (s <- summary(flomarriage ~ I(terms))) # \dontshow{ stopifnot(identical(s, summary(flomarriage ~ degree(0:5)))) # }
Run the code above in your browser using DataLab