| I-ergmTerm | R Documentation |
This is a convenience operator that can be used to paste terms constructed elsewhere into a formula.
# binary: I(formula)
# valued: I(formula)
formula |
a one-sided |
formula can also be a term_list or character. In
the latter case, if there are multiple strings, they will be
concatenated with +, and if they do not start with "~", one
will be prepended. Its environment will be inherited from the
top-level formula.
base::I() (a.k.a. AsIs)
ergmTerm for index of model terms currently visible to the package.
data(florentine)
(terms <- paste0("degree(", 0:5, ")"))
(s <- summary(flomarriage ~ I(terms)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.