Functions that have been superceed, were never documented, or will be removed from the package for other reasons
# S3 method for ergm
coef(object, ...)# S3 method for ergm
$(x, name)
InitErgmTerm.degreepopularity(nw, arglist, ...)
InitErgmTerm.hammingmix(nw, arglist, ..., version = packageVersion("ergm"))
InitErgmTerm.idegreepopularity(nw, arglist, ...)
InitErgmTerm.odegreepopularity(nw, arglist, ...)
# S3 method for ergm
san(
object,
formula = object$formula,
constraints = object$constraints,
target.stats = object$target.stats,
nsim = NULL,
basis = NULL,
output = c("network", "edgelist", "ergm_state"),
only.last = TRUE,
control = object$control$SAN,
verbose = FALSE,
offset.coef = NULL,
...
)
offset.info.formula(object, ...)
See Extract.
Arguments to deprecated functions.
coef(ergm): extracts the ergm parameters; may be
removed in favour of the default method once the number of ergm
objects with $coef elements in the wild is sufficiently low.
$: accesses elements of ergm objects;
needed for backwards compatibility when components get renamed.
InitErgmTerm.degreepopularity(): Use degree1.5 instead.
InitErgmTerm.idegreepopularity(): Use idegree1.5 instead.
InitErgmTerm.odegreepopularity(): Use odegree1.5 instead.
san(ergm): The developers are not aware of a use case for this function. Please contact them if you would like to prevent its removal.
offset.info.formula(): offset.info.formula returns the offset
vectors associated with a formula.