ergm.bridge.llr that uses a
dyad-independent ERGM as a starting point for bridge sampling to
estimate the log-likelihood for a given dyad-dependent model and
parameter configuration. The dyad-independent model may be specified
or can be chosen adaptively.ergm.bridge.dindstart.llk(object,
response=NULL,
constraints=~.,
coef,
dind=NULL,
coef.dind=NULL,
basis=NULL,
...,
llkonly=TRUE,
control=control.ergm.bridge())ergm for details.ergm.bridge.dindstart.llk can only handle binary ERGMs.ergm for
details. Note that only constraints that do not induce dyadic
dependence can be handled by ergm.bridge.dindstart.llk.object with an overal density term (edges)
added if not redundant.dind.network object to start
the Markov chain. If omitted, the default is the left-hand-side of
the object.ergm.bridge.llr and simulate.formula.ergm.TRUE.)control.ergm.bridge.llkonly=TRUE, returns the scalar
log-likelihood. Otherwise, returns a copy of the list returned by
ergm.bridge.llr in addition to the following components:ergm.bridge.llr, simulate.formula.ergm